@@ -86,7 +86,7 @@ static gint client_signals[LAST_SIGNAL] = { 0 };
 
 static const char *sm_client_id_arg_name G_GNUC_UNUSED = "--sm-client-id";
 static const char *sm_config_prefix_arg_name G_GNUC_UNUSED = "--sm-config-prefix";
-#ifdef HAVE_GDK_SCREEN_GET_NUMBER
+#ifdef HAVE_GTK_MULTIHEAD
 static const char *sm_screen G_GNUC_UNUSED = "--screen";
 #endif
 
@@ -436,7 +436,7 @@ client_set_restart_command (GnomeClient *client)
   gchar **ptr;
   gint    i = 0;
 
-#ifdef HAVE_GDK_SCREEN_GET_NUMBER
+#ifdef HAVE_GTK_MULTIHEAD
   gint disp;
   gchar *tmp;
 #endif
@@ -451,7 +451,7 @@ client_set_restart_command (GnomeClient *client)
   /* Add space for static arguments, config prefix and client id. */
   argc += g_list_length (client->static_args) + 4;
 
-#ifdef HAVE_GDK_SCREEN_GET_NUMBER
+#ifdef HAVE_GTK_MULTIHEAD
   /* add two more for --screen */
   argc += 2;
 #endif
@@ -475,9 +475,9 @@ client_set_restart_command (GnomeClient *client)
   vals[i].length = strlen (client->client_id);
   vals[i++].value = client->client_id;
 
-#ifdef HAVE_GDK_SCREEN_GET_NUMBER
+#ifdef HAVE_GTK_MULTIHEAD
   /* set the screen number */
-  disp = gdk_screen_get_number (gdk_get_default_screen ());
+  disp = gdk_screen_get_number (gdk_screen_get_default ());
   tmp = g_strdup_printf ("%d", disp);
   vals[i].length = strlen (sm_screen);
   vals[i++].value = (char *)sm_screen;
@@ -1143,19 +1143,19 @@ master_client_disconnect (GnomeClient *client,
  * gnome_master_client
  *
  * Description:
- * Get the master session management client.  This master client gets
-   a client id, that may be specified by the '--sm-client-id' command
-   line option.  A master client will be generated by 'gnome-init'.
-   If possible the master client will contact the session manager
-   after command-line parsing is finished (unless
-   'gnome_client_disable_master_connection' was called).  The master
-   client will also set the SM_CLIENT_ID property on the client leader
-   window of your application.
-
-   Additionally, the master client gets some static arguments set
-   automatically (see 'gnome_client_add_static_arg' for static
-   arguments): 'gnome_init' passes all the command line options which
-   are recognised by gtk as static arguments to the master client.
+ * Get the master session management client.  This master client gets a client
+ * id, that may be specified by the '--sm-client-id' command line option.  A
+ * master client will be generated by gnome_program_init().  If possible the
+ * master client will contact the session manager after command-line parsing is
+ * finished (unless gnome_client_disable_master_connection() was called). The
+ * master client will also set the SM_CLIENT_ID property on the client leader
+ * window of your application.
+ *
+ * Additionally, the master client gets some static arguments set automatically
+ * (see gnome_client_add_static_arg() for static arguments):
+ * gnome_program_init() passes all the command line options which are
+ * recognised by gtk as static arguments to the master client.
+ *
  * Returns:  Pointer to the master client
  **/
 
@@ -1365,13 +1365,11 @@ gnome_real_client_finalize (GObject *object)
 /**
  * gnome_client_new
  *
- * Description: Allocates memory for a new GNOME session management
- * client object.  After allocating, the client tries to connect to a
- * session manager. You probably want to use
- * <function>gnome_master_client()</function> instead.
+ * Description: Allocates memory for a new GNOME session management client
+ * object. After allocating, the client tries to connect to a session manager.
+ * You probably want to use gnome_master_client() instead.
  *
- * Returns: Pointer to a newly allocated GNOME session management
- * client object.
+ * Returns: Pointer to a newly allocated GNOME session management client object.
  **/
 
 GnomeClient *
@@ -1390,12 +1388,10 @@ gnome_client_new (void)
 /**
  * gnome_client_new_without_connection
  *
- * Description: Allocates memory for a new GNOME session management
- * client object. You probably want to use
- * <function>gnome_master_client()</function> instead.
+ * Description: Allocates memory for a new GNOME session management client
+ * object. You probably want to use gnome_master_client() instead.
  *
- * Returns: Pointer to a newly allocated GNOME session management
- * client object.
+ * Returns: Pointer to a newly allocated GNOME session management client object.
  **/
 
 GnomeClient *
@@ -1423,12 +1419,12 @@ gnome_client_new_without_connection (void)
 
 /**
  * gnome_client_flush
- * @client: Pointer to GNOME session client object.
+ * @client: A #GnomeClient instance.
  *
  * Description:
- * This will force the underlying connection to the session manager to
- * be flushed.  This is useful if you have some pending changes that
- * you want to make sure get committed.
+ * This will force the underlying connection to the session manager to be
+ * flushed. This is useful if you have some pending changes that you want to
+ * make sure get committed.
  **/
 
 void
@@ -1452,7 +1448,7 @@ gnome_client_flush (GnomeClient *client)
 
 /**
  * gnome_client_connect
- * @client: Pointer to GNOME session client object.
+ * @client: A #GnomeClient instance.
  *
  * Description: Causes the client to connect to the session manager.
  * Usually happens automatically; no need to call this function.
@@ -1528,7 +1524,7 @@ gnome_client_connect (GnomeClient *client)
 
 /**
  * gnome_client_disconnect
- * @client: Pointer to GNOME session client object.
+ * @client: A #GnomeClient instance.
  *
  * Description: Disconnect the client from the session manager.
  **/
@@ -1552,22 +1548,9 @@ gnome_client_disconnect (GnomeClient *client)
  * gnome_client_get_flags:
  * @client: Pointer to GNOME session client object.
  *
- * Description:
+ * Description: Determine the client's status with the session manager.,
  *
- * Returns some flags, that give additional information about this
- * client.  Right now, the following flags are supported:
- *
- * - GNOME_CLIENT_IS_CONNECTED: The client is connected to a session
- *   manager (It's the same information like using *
- *   GNOME_CLIENT_CONNECTED).
- *
- * - GNOME_CLIENT_RESTARTED: The client has been restarted, i. e. it
- *   has been running with the same client id before.
- *
- * - GNOME_CLIENT_RESTORED: This flag is only used for the master
- *   client.  It indicates, that there may be a configuraion file from
- *   which the clients state should be restored (using the
- *   gnome_client_get_config_prefix call).
+ * Returns: Various #GnomeClientFlag flags which have been or'd together.
  **/
 
 GnomeClientFlags
@@ -1603,10 +1586,11 @@ gnome_client_get_flags (GnomeClient *client)
 /**
  * gnome_client_set_clone_command
  * @client: Pointer to GNOME session client object.
- * @argc: number of strings in the argv vector
- * @argv[]: argument strings, suitable for use with <function>execv()</function>
+ * @argc: Number of strings in the @argv vector.
+ * @argv: Argument strings, suitable for use with execv().
  *
- * Description: Set a command the session manager can use to create a new instance of the application.
+ * Description: Set a command the session manager can use to create a new
+ * instance of the application.
  **/
 
 void
@@ -1628,9 +1612,10 @@ gnome_client_set_clone_command (GnomeClient *client,
 /**
  * gnome_client_set_current_directory
  * @client: Pointer to GNOME session client object.
- * @dir: Directory path
+ * @dir: Directory path.
  *
- * Description: Set the directory to be in when running shutdown, discard, restart, etc. commands.
+ * Description: Set the directory to be in when running shutdown, discard,
+ * restart, etc. commands.
  **/
 
 void
@@ -1664,21 +1649,9 @@ gnome_client_set_current_directory (GnomeClient *client,
 /**
  * gnome_client_set_discard_command
  * @client: Pointer to GNOME session client object.
- * @argc: Number of strings in argv
- * @argv[]: Vector of strings such as those passed to <function>execv()</function>
+ * @argc: Number of strings in argv.
+ * @argv: Vector of strings such as those passed to execv().
  *
- * Description: Provides a command to run when a client is removed
- * from the session. It might delete session-specific config files for
- * example.  Executing the discard command on the local host should
- * delete the information saved as part of the session save that was
- * in progress when the discard command was set. For example:
-
-<example>
-     gchar *prefix = gnome_client_get_config_prefix (client);
-     gchar *argv[] = { "rm", "-r", NULL };
-     argv[2] = gnome_config_get_real_path (prefix);
-     gnome_client_set_discard_command (client, 3, argv);
-</example>
  **/
 
 void
@@ -1769,11 +1742,11 @@ gnome_client_set_environment (GnomeClient *client,
 /**
  * gnome_client_set_process_id
  * @client: Pointer to GNOME session client object.
- * @pid: PID to set as the client's PID
+ * @pid: PID to set as the client's PID.
  *
- * Description: The client should tell the session manager the result
- * of <function>getpid()</function>. However, Gnome does this
- * automatically; so you don't need this function.
+ * Description: The client should tell the session manager the result of
+ * getpid(). However, GNOME does this automatically; so you do not need this
+ * function.
  **/
 
 void
@@ -1798,10 +1771,10 @@ gnome_client_set_process_id (GnomeClient *client, pid_t pid)
 /**
  * gnome_client_set_program
  * @client: Pointer to GNOME session client object.
- * @program: name of the program
+ * @program: Name of the program.
  *
- * Description: Used to tell the session manager the name of your program. Set automatically;
- * this function isn't needed.
+ * Description: Used to tell the session manager the name of your program. Set
+ * automatically; this function isn't needed.
  **/
 
 void
@@ -1830,19 +1803,18 @@ gnome_client_set_program (GnomeClient *client,
 /**
  * gnome_client_set_resign_command
  * @client: Pointer to GNOME session client object.
- * @argc: number of strings in argv
- * @argv[]: <function>execv()</function>-style command to undo the effects of the client.
+ * @argc: Number of strings in @argv.
+ * @argv: execv()-style command to undo the effects of the client.
  *
- * Description: Some clients can be "undone," removing their effects and deleting any
- * saved state. For example, xmodmap could register a resign command to undo the keymap
- * changes it saved.
+ * Description: Some clients can be "undone," removing their effects and
+ * deleting any saved state. For example, xmodmap could register a resign
+ * command to undo the keymap changes it saved.
  *
- * Used by clients that use the GNOME_RESTART_ANYWAY restart style to
- * to undo their effects (these clients usually perform initialisation
- * functions and leave effects behind after they die).  The resign
- * command combines the effects of a shutdown command and a discard
- * command. It is executed when the user decides that the client
- * should cease to be restarted.
+ * Used by clients that use the #GNOME_RESTART_ANYWAY restart style to to undo
+ * their effects (these clients usually perform initialisation functions and
+ * leave effects behind after they die). The resign command combines the
+ * effects of a shutdown command and a discard command. It is executed when the
+ * user decides that the client should cease to be restarted.
  **/
 
 void
@@ -1879,15 +1851,14 @@ gnome_client_set_resign_command (GnomeClient *client,
 /**
  * gnome_client_set_restart_command
  * @client: Pointer to GNOME session client object.
- * @argc: number of strings in argv
- * @argv: argument vector to <function>execv()</function> to restart the client
+ * @argc: Number of strings in argv.
+ * @argv: Argument vector to an execv() to restart the client.
  *
- * Description: When clients crash or the user logs out and back in,
-   they are restarted.  * This command should perform the restart.  *
-   Executing the restart command on the local host should reproduce
-   the state of the client at the time of the session save as closely
-   as possible. Saving config info under the
-   gnome_client_get_config_prefix is generally useful.
+ * Description: When clients crash or the user logs out and back in, they are
+ * restarted. This command should perform the restart.  Executing the restart
+ * command on the local host should reproduce the state of the client at the
+ * time of the session save as closely as possible. Saving config info under
+ * the gnome_client_get_config_prefix() is generally useful.
  **/
 
 void
@@ -1942,15 +1913,10 @@ gnome_client_set_priority (GnomeClient *client, guint priority)
 /**
  * gnome_client_set_restart_style
  * @client: Pointer to GNOME session client object.
- * @style: When to restart the client
+ * @style: When to restart the client.
  *
- * Description: GNOME_RESTART_IF_RUNNING causes the client to be
- * restarted in the next session if it was running when the previous
- * session exited. Restart is done via the restart command you
- * set. GNOME_RESTART_ANYWAY means the client will be restarted even
- * if the user exits the client before logging
- * out. GNOME_RESTART_IMMEDIATELY restarts the client immediately
- * anytime it crashes or is exited.
+ * Tells the session manager how the client should be restarted in future
+ * session. The options are given by the #GnomeRestartStyle enum.
  **/
 
 void
@@ -1999,8 +1965,8 @@ gnome_client_set_restart_style (GnomeClient *client,
 /**
  * gnome_client_set_shutdown_command
  * @client: Pointer to GNOME session client object.
- * @argc: number of strings in argv
- * @argv[]: command to shutdown the client if the client isn't running
+ * @argc: Number of strings in argv.
+ * @argv: Command to shutdown the client if the client isn't running.
  *
  * Description: GNOME_RESTART_ANYWAY clients can set this command to run
  * when the user logs out but the client is no longer running.
@@ -2046,9 +2012,9 @@ gnome_client_set_shutdown_command (GnomeClient *client,
 /**
  * gnome_client_set_user_id
  * @client: Pointer to GNOME session client object.
- * @id: Username
+ * @id: Username.
  *
- * Description: Tell the session manager the user's login name. Gnome
+ * Description: Tell the session manager the user's login name. GNOME
  * does this automatically; no need to call the function.
  **/
 
@@ -2075,15 +2041,14 @@ gnome_client_set_user_id (GnomeClient *client,
 /**
  * gnome_client_add_static_arg
  * @client: Pointer to GNOME session client object.
- * @...: NULL-terminated list of arguments to add to the restart command
+ * @...: %NULL-terminated list of arguments to add to the restart command.
  *
- * Description: You can add arguments to your restart command argv
-   with this function. This function provides an alternative way of
-   adding new arguments to the restart command. The arguments are
-   placed before the arguments specified by
-   'gnome_client_set_restart_command' and after the arguments
-   recognised by gtk specified by the user on the original command
-   line.
+ * Description: You can add arguments to your restart command's argv with this
+ * function. This function provides an alternative way of adding new arguments
+ * to the restart command. The arguments are placed before the arguments
+ * specified by gnome_client_set_restart_command() and after the arguments
+ * recognised by GTK+ that are specified by the user on the original command
+ * line.
  **/
 
 void
@@ -2110,12 +2075,12 @@ gnome_client_add_static_arg (GnomeClient *client, ...)
 
 /**
  * gnome_client_set_id
- * @client: Pointer to GNOME session client object.
- * @id: Session management ID
+ * @client: A #GnomeClient instance.
+ * @id: Session management ID.
  *
  * Description: Set the client's session management ID; must be done
- * before connecting to the session manager. Frankly I have no idea
- * why you'd do this.
+ * before connecting to the session manager. There is usually no reason to call
+ * this function.
  **/
 
 void
@@ -2135,11 +2100,12 @@ gnome_client_set_id (GnomeClient *client, const gchar *id)
 
 /**
  * gnome_client_get_id
- * @client: Pointer to GNOME session client object.
+ * @client: A #GnomeClient instance.
  *
  * Description: Returns session management ID
  *
- * Returns:  Session management ID for this client; NULL if not connected to a session manager.
+ * Returns:  Session management ID for this client; %NULL if not connected to a
+ * session manager.
  **/
 
 const gchar *
@@ -2153,12 +2119,12 @@ gnome_client_get_id (GnomeClient *client)
 
 /**
  * gnome_client_get_previous_id
- * @client: Pointer to GNOME session client object.
+ * @client: A #GnomeClient instance.
  *
- * Description: Get the previous session management ID (from previous session)
+ * Description: Get the session management ID from the previous session.
  *
  * Returns: Pointer to the session management ID the client had in the last
- * session, or NULL if it wasn't in a previous session.
+ * session, or %NULL if it was not in a previous session.
  **/
 
 const gchar *
@@ -2172,15 +2138,15 @@ gnome_client_get_previous_id (GnomeClient *client)
 
 /**
  * gnome_client_get_desktop_id:
- * @client: a #GnomeClient
+ * @client: A #GnomeClient instance.
  *
  * Get the client ID of the desktop's current instance, i.e.  if
  * you consider the desktop as a whole as a session managed app, this
  * returns its session ID using a GNOME extension to session
  * management. May return %NULL for apps not running under a recent
- * version of gnome-session, apps should handle that case.
+ * version of gnome-session; apps should handle that case.
  *
- * Return value: session ID of GNOME desktop instance, or %NULL if none
+ * Returns: Session ID of GNOME desktop instance, or %NULL if none.
  **/
 const gchar*
 gnome_client_get_desktop_id (GnomeClient *client)
@@ -2198,10 +2164,11 @@ gnome_client_get_desktop_id (GnomeClient *client)
  * provides a suitable place to store any details about the state of
  * the client which can not be described using the app's command line
  * arguments (as set in the restart command). You may push the
- * returned value using 'gnome_config_push_prefix' and read or write
- *  any values you require.
+ * returned value using gnome_config_push_prefix() and read or write
+ * any values you require.
  *
- * Returns: Config prefix.
+ * Returns: Config prefix. The returned string belongs to libgnomeui library
+ * and should NOT be freed by the caller.
  **/
 
 const gchar *
@@ -2226,20 +2193,20 @@ static gchar* config_prefix = NULL;
 /**
  * gnome_client_set_global_config_prefix
  * @client: Pointer to GNOME session client object.
- * @prefix: Prefix for saving the global configuration
+ * @prefix: Prefix for saving the global configuration.
  *
- * Description:  Set the value used for the global config prefix. The config prefixes
-   returned by gnome_client_get_config_prefix are formed by extending
-   this prefix with an unique identifier.
-
-   The global config prefix defaults to a name based on the name of
-   the executable. This function allows you to set it to a different
-   value. It should be called BEFORE retrieving the config prefix for
-   the first time. Later calls will be ignored.
-
-   For example, setting a global config prefix of "/app.d/session/"
-   would ensure that all your session save files or directories would
-   be gathered together into the app.d directory.
+ * Description:  Set the value used for the global config prefix. The config
+ * prefixes returned by gnome_client_get_config_prefix() are formed by
+ * extending this prefix with an unique identifier.
+ *
+ * The global config prefix defaults to a name based on the name of
+ * the executable. This function allows you to set it to a different
+ * value. It should be called BEFORE retrieving the config prefix for
+ * the first time. Later calls will be ignored.
+ *
+ * For example, setting a global config prefix of "/app.d/session/"
+ * would ensure that all your session save files or directories would
+ * be gathered together into the app.d directory.
  **/
 
 void
@@ -2261,17 +2228,17 @@ gnome_client_set_global_config_prefix (GnomeClient *client, const gchar* prefix)
  * @client: Pointer to GNOME session client object.
  *
  * Description: Get the config prefix that will be returned by
- * #gnome_client_get_config_prefix() for clients
- * which have NOT been restarted or cloned (i.e. for clients started
- * by the user without `--sm-' options). This config prefix may be
- * used to write the user's preferred config for these "new" clients.
+ * gnome_client_get_config_prefix() for clients which have NOT been restarted
+ * or cloned (i.e. for clients started by the user without `--sm-' options).
+ * This config prefix may be used to write the user's preferred config for
+ * these "new" clients.
  *
- * You could also use this prefix as a place to store and retrieve
- * config details that you wish to apply to ALL instances of the
- * app. However, this practice limits the users freedom to configure
- * each instance in a different way so it should be used with caution.
+ * You could also use this prefix as a place to store and retrieve config
+ * details that you wish to apply to ALL instances of the app. However, this
+ * practice limits the users freedom to configure each instance in a different
+ * way so it should be used with caution.
  *
- * Returns:  The config prefix as a newly allocated string
+ * Returns:  The config prefix as a newly allocated string.
  **/
 
 const gchar *
@@ -2522,15 +2489,15 @@ gnome_client_save_dialog_show (GnomeClient *client, gint key,
 
 /**
  * gnome_client_save_any_dialog
- * @client: Pointer to GNOME session client object.
- * @dialog: Pointer to GNOME dialog widget.
+ * @client: Pointer to #GnomeClient object.
+ * @dialog: Pointer to GNOME dialog widget (a #GtkDialog widget).
  *
  * Description:
  * May be called during a "save_youself" handler to request that a
  * (modal) dialog is presented to the user. The session manager decides
- * when the dialog is shown but it will not be shown it unless the
- * interact_style == GNOME_INTERACT_ANY. A "Cancel Logout" button
- * will be added during a shutdown.
+ * when the dialog is shown, but it will not be shown it unless the
+ * session manager is sending an interaction style of #GNOME_INTERACT_ANY.
+ * "Cancel" and "Log out" buttons will be added during a shutdown.
  **/
 void
 gnome_client_save_any_dialog (GnomeClient *client, GtkDialog *dialog)
@@ -2549,14 +2516,15 @@ gnome_client_save_any_dialog (GnomeClient *client, GtkDialog *dialog)
 
 /**
  * gnome_client_save_error_dialog
- * @client: Pointer to GNOME session client object.
- * @dialog: Pointer to GNOME dialog widget.
+ * @client: Pointer to #GnomeClient object.
+ * @dialog: Pointer to GNOME dialog widget (a #GtkDialog widget).
  *
  * Description:
  * May be called during a "save_youself" handler when an error has occured
- * during the save. The session manager decides when the dialog is shown
- * but it will not be shown when the interact_style == GNOME_INTERACT_NONE.
- * A "Cancel Logout" button will be added during a shutdown.
+ * during the save. The session manager decides when the dialog is shown, but
+ * it will not be shown it unless the session manager is sending an interaction
+ * style of #GNOME_INTERACT_ANY. "Cancel" and "Log out" buttons will be added
+ * during a shutdown.
  **/
 
 void
@@ -2576,20 +2544,23 @@ gnome_client_save_error_dialog (GnomeClient *client, GtkDialog *dialog)
 
 /**
  * gnome_client_request_interaction
- * @client: Pointer to GNOME session client object.
- * @dialog_type: What sort of dialog to create
- * @function: Callback to invoke to perform the interaction
- * @data: callback data
+ * @client: A #GnomeClient object.
+ * @dialog_type: The type of dialog to create.
+ * @function: Callback to invoke to perform the interaction.
+ * @data: Callback data.
  *
- * Description: Use the following functions, if you want to interact
- * with the user during a "save_yourself" handler without being
- * restricted to using the dialog based commands
- * gnome_client_save_[any/error]_dialog.  If and when the session
- * manager decides that it's the app's turn to interact then 'func'
- * will be called with the specified arguments and a unique
- * 'GnomeInteractionKey'. The session manager will block other clients
- * from interacting until this key is returned with
- * 'gnome_interaction_key_return'.
+ * Description: Use the following functions, if you want to interact with the
+ * user during a "save_yourself" handler without being restricted to using the
+ * dialog based commands gnome_client_save_any_dialog() or
+ * gnome_client_save_error_dialog(). Note, however, that overriding the session
+ * manager specified preference in this way (by using arbitrary dialog boxes)
+ * is not very nice.
+ *
+ * If and when the session manager decides that it's the app's turn to interact
+ * then 'func' will be called with the specified arguments and a unique
+ * 'GnomeInteractionKey'. The session manager will block other
+ * clients from interacting until this key is returned with
+ * gnome_interaction_key_return().
  **/
 
 void
@@ -2616,12 +2587,13 @@ gnome_client_request_interaction (GnomeClient *client,
 /**
  * gnome_client_request_interaction_interp
  * @client: Pointer to GNOME session client object.
- * @dialog_type: Type of dialog to show
- * @function: callback to perform the interaction
- * @data: callback data
- * @destroy: function to destroy callback data
+ * @dialog_type: Type of dialog to show.
+ * @function: Callback to perform the interaction (a #GnomeInteractFunction).
+ * @data: Callback data.
+ * @destroy: Function to destroy callback data.
  *
- * Description: Used when you need to destroy the callback data after the interaction.
+ * Description: Similar to gnome_client_request_interaction(), but used when
+ * you need to destroy the callback data after the interaction.
  **/
 
 void
@@ -2653,13 +2625,13 @@ gnome_client_request_interaction_interp (GnomeClient *client,
 
 /**
  * gnome_client_request_phase_2
- * @client: Pointer to GNOME session client object.
+ * @client: A #GnomeClient object.
  *
- * Description:  Request the session managaer to emit the "save_yourself" signal for
-   a second time after all the clients in the session have ceased
-   interacting with the user and entered an idle state. This might be
-   useful if your app manages other apps and requires that they are in
-   an idle state before saving its final data.
+ * Description:  Request the session managaer to emit the "save_yourself"
+ * signal for a second time after all the clients in the session have ceased
+ * interacting with the user and entered an idle state. This might be useful if
+ * your app manages other apps and requires that they are in an idle state
+ * before saving its final data.
  **/
 
 void
@@ -2678,24 +2650,24 @@ gnome_client_request_phase_2 (GnomeClient *client)
 /**
  * gnome_client_request_save
  * @client: Pointer to GNOME session client object.
- * @save_style: Save style to request
- * @shutdown: Whether to log out of the session
- * @interact_style: whether to allow user interaction
- * @fast: minimize activity to save ASAP
- * @global: request that all other apps in the session also save
+ * @save_style: Save style to request.
+ * @shutdown: Whether to log out of the session.
+ * @interact_style: Whether to allow user interaction.
+ * @fast: Minimize activity to save as soon as possible.
+ * @global: Request that all other apps in the session also save their state.
  *
  * Description: Request the session manager to save the session in
  * some way. The arguments correspond with the arguments passed to the
  * "save_yourself" signal handler.
  *
  * The save_style indicates whether the save should affect data
- * accessible to other users (GNOME_SAVE_GLOBAL) or only the state
- * visible to the current user (GNOME_SAVE_LOCAL) or both. Setting
- * shutdown to TRUE will initiate a logout. The interact_style
+ * accessible to other users (#GNOME_SAVE_GLOBAL) or only the state
+ * visible to the current user (#GNOME_SAVE_LOCAL) or both. Setting
+ * shutdown to %TRUE will initiate a logout. The interact_style
  * specifies which kinds of interaction will be available. Setting
- * fast to TRUE will limit the save to setting the session manager
+ * fast to %TRUE will limit the save to setting the session manager
  * properties plus any essential data.  Setting the value of global to
- * TRUE will request that all the other apps in the session do a save
+ * %TRUE will request that all the other apps in the session do a save
  * as well. A global save is mandatory when doing a shutdown.
  *
  **/
@@ -2796,10 +2768,10 @@ gnome_client_request_save (GnomeClient	       *client,
 /**
  * gnome_interaction_key_return
  * @key: Key passed to interaction callback
- * @cancel_shutdown: if TRUE then cancel the shutdown
+ * @cancel_shutdown: If %TRUE, cancel the shutdown
  *
  * Description: Used in interaction callback to tell the session manager
- * you're done interacting
+ * you are done interacting.
  **/
 
 void
